diff --git a/autoconfig b/autoconfig
index 2cfb247..e660083 100644
--- a/autoconfig
+++ b/autoconfig
@@ -112,6 +112,7 @@ CONFIG_SERVICES='yes'         # check for services to run, provided via bootpara
 CONFIG_SETKEYCODES='yes'      # run setkeycodes when bootoption setkeycodes found
 CONFIG_SMALL='yes'            # use a less "bloat" /etc/inittab for small computer with less RAM
 CONFIG_SSH='yes'              # check for bootparam ssh
+CONFIG_VNC='yes'	      # check for bootparam vnc
 CONFIG_SWRAID='yes'           # check for software raid devices [only in live-mode]
 CONFIG_SWSPEAK='yes'          # run software synthesizer via speakup
 CONFIG_TESTCD='yes'           # CD checker
diff --git a/autoconfig.functions b/autoconfig.functions
index f9a70ba..26ad30d 100755
--- a/autoconfig.functions
+++ b/autoconfig.functions
@@ -1501,6 +1501,51 @@ fi
 }
 # }}}
 
+# {{{ autostart of x11vnc
+config_vnc(){
+USER=grml # TODO: make it dynamically configurable
+if checkbootparam 'vnc' ; then
+   VNC_PASSWD=''
+   VNC_PASSWD="$(getbootparam 'vnc' 2>>$DEBUG)"
+   einfo "Bootoption vnc found, trying to set password for user $USER."
+   eindent
+   if [ -z "$VNC_PASSWD" ] ; then
+      if [ -x /usr/bin/apg ] ; then
+         VNC_PASSWD="$(apg -M NL -a 0 -m 8 -x 12 -n 1)"
+      elif [ -x /usr/bin/gpw ] ; then
+         VNC_PASSWD="$(gpw 1)"
+      elif [ -x /usr/bin/pwgen ] ; then
+         VNC_PASSWD="$(pwgen -1 8)"
+      elif [ -x /usr/bin/hexdump ] ; then
+         VNC_PASSWD="$(dd if=/dev/urandom bs=14 count=1 2>/dev/null | hexdump | awk '{print $3 $4}')"
+      elif [ -n "$RANDOM" ] ; then
+         VNC_PASSWD="grml${RANDOM}"
+      else
+         VNC_PASSWD=''
+         eerror "Empty passphrase and neither pwgen nor hexdump nor \$RANDOM found. Skipping."
+         eend 1
+      fi
+
+      if [ -n "$VNC_PASSWD" ] ; then
+         ewarn "No given password for vnc found. Using random password: $VNC_PASSWD" ; eend 0
+      fi
+   fi
+   eoutdent
+
+   # finally check if we have a password we can use:
+   if [ -n "$VNC_PASSWD" ] ; then
+      mkdir /home/$USER/.vnc 
+      if [ ! -x /usr/bin/x11vnc ] ; then
+         eerror "x11vnc not found. Skipping."
+      else 
+         /usr/bin/x11vnc -storepasswd "$VNC_PASSWD" /home/grml/.vnc/passwd
+         /bin/chown -R $USER: /home/grml/.vnc
+      fi
+   fi
+fi
+}
+# }}}
+
 # {{{ set password for user grml
 config_passwd(){
 if checkbootparam 'passwd' >>$DEBUG 2>&1; then
diff --git a/grml-autoconfig b/grml-autoconfig
index 03febd7..f0e0702 100755
--- a/grml-autoconfig
+++ b/grml-autoconfig
@@ -194,6 +194,8 @@ checkvalue $CONFIG_CPU && config_cpu
 
 checkvalue $CONFIG_SSH && config_ssh
 
+checkvalue $CONFIG_VNC && config_vnc
+
 checkvalue $CONFIG_PASSWD && config_passwd
 
 checkvalue $CONFIG_EXTRACT  && config_extract
